# Skyborn: A Collection of Tools for My Research

Skyborn is a collection of functions I use in my general research, primarily for personal use.

## Installation

To install the Skyborn package, you can use pip:

```bash
pip install skyborn
```
